You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2016/02/27 16:33:39 UTC

camel git commit: Lets use undertow in this example so we try as many rest components in our examples.

Repository: camel
Updated Branches:
  refs/heads/master fa457b6e0 -> 3f6aa3ec1


Lets use undertow in this example so we try as many rest components in our examples.


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/3f6aa3ec
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/3f6aa3ec
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/3f6aa3ec

Branch: refs/heads/master
Commit: 3f6aa3ec16c915e0ed8c73132a88093f28e37250
Parents: fa457b6
Author: Claus Ibsen <da...@apache.org>
Authored: Sat Feb 27 16:33:11 2016 +0100
Committer: Claus Ibsen <da...@apache.org>
Committed: Sat Feb 27 16:33:11 2016 +0100

----------------------------------------------------------------------
 examples/camel-example-swagger-cdi/pom.xml                     | 6 +++---
 .../java/org/apache/camel/example/cdi/UserRouteBuilder.java    | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/3f6aa3ec/examples/camel-example-swagger-cdi/pom.xml
----------------------------------------------------------------------
diff --git a/examples/camel-example-swagger-cdi/pom.xml b/examples/camel-example-swagger-cdi/pom.xml
index 0117a5c..b2f673c 100644
--- a/examples/camel-example-swagger-cdi/pom.xml
+++ b/examples/camel-example-swagger-cdi/pom.xml
@@ -30,21 +30,21 @@
 
   <dependencies>
 
+    <!-- camel -->
     <dependency>
       <groupId>org.apache.camel</groupId>
       <artifactId>camel-cdi</artifactId>
     </dependency>
-
     <dependency>
       <groupId>org.apache.camel</groupId>
       <artifactId>camel-swagger-java</artifactId>
     </dependency>
-
     <dependency>
       <groupId>org.apache.camel</groupId>
-      <artifactId>camel-netty4-http</artifactId>
+      <artifactId>camel-undertow</artifactId>
     </dependency>
 
+    <!-- for json support -->
     <dependency>
       <groupId>org.apache.camel</groupId>
       <artifactId>camel-jackson</artifactId>

http://git-wip-us.apache.org/repos/asf/camel/blob/3f6aa3ec/examples/camel-example-swagger-cdi/src/main/java/org/apache/camel/example/cdi/UserRouteBuilder.java
----------------------------------------------------------------------
diff --git a/examples/camel-example-swagger-cdi/src/main/java/org/apache/camel/example/cdi/UserRouteBuilder.java b/examples/camel-example-swagger-cdi/src/main/java/org/apache/camel/example/cdi/UserRouteBuilder.java
index a409c0e..8d22408 100644
--- a/examples/camel-example-swagger-cdi/src/main/java/org/apache/camel/example/cdi/UserRouteBuilder.java
+++ b/examples/camel-example-swagger-cdi/src/main/java/org/apache/camel/example/cdi/UserRouteBuilder.java
@@ -32,9 +32,9 @@ public class UserRouteBuilder extends RouteBuilder {
     @Override
     public void configure() throws Exception {
 
         // configure we want to use servlet as the component for the rest DSL
         // and we enable json binding mode
-        restConfiguration().component("netty4-http")
+        restConfiguration().component("undertow")
             // use json binding mode so Camel automatic binds json <--> pojo
             .bindingMode(RestBindingMode.json)
             // and output using pretty print
@@ -32,9 +32,9 @@ public class UserRouteBuilder extends RouteBuilder {
     public void configure() throws Exception {
 
-        // configure we want to use servlet as the component for the rest DSL
+        // configure we want to use undertow as the component for the rest DSL
         // and we enable json binding mode